==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/hr.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Dijeljenje resursa s poslužitelja na poslužitelj s ovog poslužitelja nije omogućeno.",
    "Invalid or untrusted SSL certificate" : "Neispravna ili nepouzdana SSL potvrda",
    "Couldn't add remote share" : "Udaljeni zajednički resurs nije moguće dodati",
    "Shared with you" : "Podijeljeno s vama",
    "Shared with others" : "Podijeljeno s ostalima",
    "Shared by link" : "POdijeljeno putem veze",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Želite li dodati udaljeni zajednički resurs {name} od {owner}@{remote}?",
    "Remote share" : "Udaljeni zajednički resurs (za raspodjelu)",
    "Remote share password" : "Lozinka za udaljeni zajednički resurs",
    "Cancel" : "Odustanite",
    "Add remote share" : "Dodajte udaljeni zajednički resurs",
    "Invalid ownCloud url" : "Neispravan ownCloud URL",
    "Share" : "Dijeljenje",
    "Shared by" : "Podijeljeno od strane",
    "Sharing" : "Dijeljenje zajedničkih resursa",
    "A file or folder has been <strong>shared</strong>" : "Datoteka ili mapa su <strong>podijeljeni</strong>",
    "You shared %1$s with %2$s" : "Podijelili ste %1$s s %2$s",
    "You shared %1$s with group %2$s" : "Podijelili ste %1$s s grupom %2$s",
    "You shared %1$s via link" : "Podijelili ste %1$s putem veze",
    "%2$s shared %1$s with you" : "%2$s je %1$s podijelio s vama",
    "Shares" : "Dijeljeni resursi",
    "This share is password-protected" : "Ovaj zajednički resurs je zaštićen lozinkom",
    "The password is wrong. Try again." : "Pogrešna lozinka. Pokušajte ponovno.",
    "Password" : "Lozinka",
    "No entries found in this folder" : "Zapis nije pronadjen u ovom direktorijumu ",
    "Name" : "Naziv",
    "Share time" : "Vrijeme dijeljenja",
    "Expiration date" : "Datum isteka",
    "Sorry, this link doesn’t seem to work anymore." : "Žao nam je, čini se da ova veza više ne radi.",
    "Reasons might be:" : "Mogući razlozi su:",
    "the item was removed" : "stavka je uklonjena",
    "the link expired" : "veza je istekla",
    "sharing is disabled" : "dijeljenje je onemogućeno",
    "For more info, please ask the person who sent this link." : "Za više informacija, molimo obratite se osobi koja je ovu vezu poslala.",
    "Add to your ownCloud" : "Dodajte svome ownCloud",
    "Download" : "Preuzmite",
    "Download %s" : "Preuzmite %s",
    "Direct link" : "Izravna veza"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/hr.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Dijeljenje resursa s poslužitelja na poslužitelj s ovog poslužitelja nije omogućeno.",
    "Invalid or untrusted SSL certificate" : "Neispravna ili nepouzdana SSL potvrda",
    "Couldn't add remote share" : "Udaljeni zajednički resurs nije moguće dodati",
    "Shared with you" : "Podijeljeno s vama",
    "Shared with others" : "Podijeljeno s ostalima",
    "Shared by link" : "POdijeljeno putem veze",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Želite li dodati udaljeni zajednički resurs {name} od {owner}@{remote}?",
    "Remote share" : "Udaljeni zajednički resurs (za raspodjelu)",
    "Remote share password" : "Lozinka za udaljeni zajednički resurs",
    "Cancel" : "Odustanite",
    "Add remote share" : "Dodajte udaljeni zajednički resurs",
    "Invalid ownCloud url" : "Neispravan ownCloud URL",
    "Share" : "Dijeljenje",
    "Shared by" : "Podijeljeno od strane",
    "Sharing" : "Dijeljenje zajedničkih resursa",
    "A file or folder has been <strong>shared</strong>" : "Datoteka ili mapa su <strong>podijeljeni</strong>",
    "You shared %1$s with %2$s" : "Podijelili ste %1$s s %2$s",
    "You shared %1$s with group %2$s" : "Podijelili ste %1$s s grupom %2$s",
    "You shared %1$s via link" : "Podijelili ste %1$s putem veze",
    "%2$s shared %1$s with you" : "%2$s je %1$s podijelio s vama",
    "Shares" : "Dijeljeni resursi",
    "This share is password-protected" : "Ovaj zajednički resurs je zaštićen lozinkom",
    "The password is wrong. Try again." : "Pogrešna lozinka. Pokušajte ponovno.",
    "Password" : "Lozinka",
    "No entries found in this folder" : "Zapis nije pronadjen u ovom direktorijumu ",
    "Name" : "Naziv",
    "Share time" : "Vrijeme dijeljenja",
    "Expiration date" : "Datum isteka",
    "Sorry, this link doesn’t seem to work anymore." : "Žao nam je, čini se da ova veza više ne radi.",
    "Reasons might be:" : "Mogući razlozi su:",
    "the item was removed" : "stavka je uklonjena",
    "the link expired" : "veza je istekla",
    "sharing is disabled" : "dijeljenje je onemogućeno",
    "For more info, please ask the person who sent this link." : "Za više informacija, molimo obratite se osobi koja je ovu vezu poslala.",
    "Add to your ownCloud" : "Dodajte svome ownCloud",
    "Download" : "Preuzmite",
    "Download %s" : "Preuzmite %s",
    "Direct link" : "Izravna veza",
    "Pending" : "Na čekanju"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
